@@ -115,6 +115,9 @@ class Mooi:
 				for entry in lists[i]:
 					tokens = string.split(entry,':')
 					self.tests.remove(tokens[0])
+					if ((tokens[1].find('*SCORE*') != -1) and
+						(float(tokens[2]) > 89.0)):
+						continue
 					tests.append(tokens[0])
 					if (i < 2):
 						self.scored.append(tokens[0])
@@ -129,18 +132,11 @@ class Mooi:
 			self.bsdMode()
 			return			
 
-		if (self.modes[0]):
-			if ((self.tests != None) and (len(self.tests) != 0)):
-				next = self.tests.pop()
-				if (next in self.scored):
-					self.modes[1] = 1
-					self.modes[2] = 0
-				else:
-					self.modes[1] = 0 
-					self.modes[2] = 1
-				self.quiz = [ self.prefix + next, 0, 1]
+		if ((self.modes[0]) and (self.tests != None)): # subsequent lavengro loads
+			if (len(self.tests) != 0):
+				self.quiz = [ self.prefix + self.get_next(), 0, 1]
 				return
-			elif ((self.tests != None) and (len(self.tests) == 0)):
+			else:
 				self.exit('All tests taken.', 0)
 			
 		# choose dir/subject
@@ -178,19 +174,12 @@ class Mooi:
 			user = 'user'
 		self.record = self.prefix + user + '.lav'
 
-		if (self.modes[0]):
+		if (self.modes[0]):				# initial lavengro mode load
 			if os.path.exists(self.record):
 				self.sort(self.loadLav())
-			else:						# no testing record
+			else:					   
 				self.lav = open(self.record, 'w')
-			next = self.tests.pop()
-			if (next in self.scored):
-				self.modes[1] = 1
-				self.modes[2] = 0
-			else:
-				self.modes[1] = 0 
-				self.modes[2] = 1
-			self.quiz = [ self.prefix + next, 0, 1]
+			self.quiz = [ self.prefix + self.get_next(), 0, 1]
 		else:
 			if not self.lavLoaded:
 				self.loadLav()
@@ -200,6 +189,16 @@ class Mooi:
 			self.quiz = [ self.prefix + self.tests[choice], 0, 1]
 		return
 
+	def get_next(self):
+		next = self.tests.pop()
+		if (next in self.scored):
+			self.modes[1] = 1
+			self.modes[2] = 0
+		else:
+			self.modes[1] = 0 
+			self.modes[2] = 1
+		return next
+
 	def loadLav(self):
 		if (os.path.exists(self.record)):
 			shutil.copyfile(self.record, self.record + '.safe')
